@@ -431,8 +431,8 @@ nodesplit.plotdata <- function(nodesplit, type) {
 #' Plot raw responses over time by treatment or class
 #'
 #' @param plotby A character object that can take either `"arm"` to indicate that raw responses
-#' should be plotted separately for each study arm, or `"rel"` to indicate that the relative
-#' effects within each study should be plotted. In this way the time-course of both the absolute
+#' should be plotted separately for each study arm, or `"rel"` to indicate that the within-study
+#' relative effects/treatment differences should be plotted. In this way the time-course of both the absolute
 #' effects and the relative effects can be examined.
 #' @param ... Arguments to be sent to `ggplot()`
 #' @inheritParams plot.mb.network
@@ -440,9 +440,6 @@ nodesplit.plotdata <- function(nodesplit, type) {
 #'
 #' @return The function returns an object of `class(c("gg", "ggplot")`. Characteristics
 #' of the object can therefore be amended as with other plots generated by `ggplot()`.
-#' A message will indicate if data are assumed to be change from baseline (i.e. if there
-#' are no responses in the data at time=0). In this case responses will be set to 0 at
-#' time=0.
 #'
 #' @details Plots can be faceted by either treatment (`level="treatment"`) or class
 #' (`level="class"`) to investigate similarity of treatment responses within classes/agents.
@@ -489,26 +486,47 @@ timeplot <- function(network, level="treatment", plotby="arm", link="identity",
   }
 
   plotdata <- network$data.ab
+  cfb <- network$cfb
 
   if (plotby=="arm") {
-    # Identify if data is CFB or not
-    base.dat <- plotdata[plotdata$fupcount==1,]
-    if (any(base.dat$time!=0)) {
-      base.dat$y <- rep(0, nrow(base.dat))
-      base.dat$se <- rep(0, nrow(base.dat))
-      base.dat$time <- rep(0, nrow(base.dat))
 
-      plotdata <- rbind(base.dat, plotdata)
-      plotdata <- dplyr::arrange(plotdata, studyID, time, treatment)
+    studies <- unique(plotdata$studyID)
+    for (i in seq_along(studies)) {
+      base.dat <- subset(plotdata, fupcount==1 & studyID==studies[i])
+      if (cfb[i]==TRUE & any(base.dat$time!=0)) {
+        base.dat$y <- rep(0, nrow(base.dat))
+        base.dat$se <- rep(0, nrow(base.dat))
+        base.dat$time <- rep(0, nrow(base.dat))
 
-      # Do not run this function with pylr loaded!!
-      plotdata <- plotdata %>%
-        dplyr::group_by(studyID, time) %>%
-        dplyr::mutate(arm = sequence(dplyr::n()))
-
-      message(cat("Absence of observations with time=0 in network - data assumed to be change from baseline:",
-                  "plotting response=0 at time=0", sep="\n"))
+        plotdata <- rbind(base.dat, plotdata)
+      }
     }
+    plotdata <- dplyr::arrange(plotdata, studyID, time, treatment)
+
+    # Do not run this function with pylr loaded!!
+    plotdata <- plotdata %>%
+      dplyr::group_by(studyID, time) %>%
+      dplyr::mutate(arm = sequence(dplyr::n()))
+
+
+    # # Identify if data is CFB or not
+    # base.dat <- plotdata[plotdata$fupcount==1,]
+    # if (any(base.dat$time!=0)) {
+    #   base.dat$y <- rep(0, nrow(base.dat))
+    #   base.dat$se <- rep(0, nrow(base.dat))
+    #   base.dat$time <- rep(0, nrow(base.dat))
+    #
+    #   plotdata <- rbind(base.dat, plotdata)
+    #   plotdata <- dplyr::arrange(plotdata, studyID, time, treatment)
+    #
+    #   # Do not run this function with pylr loaded!!
+    #   plotdata <- plotdata %>%
+    #     dplyr::group_by(studyID, time) %>%
+    #     dplyr::mutate(arm = sequence(dplyr::n()))
+    #
+    #   message(cat("Absence of observations with time=0 in network - data assumed to be change from baseline:",
+    #               "plotting response=0 at time=0", sep="\n"))
+    # }
 
     g <- ggplot2::ggplot(plotdata,
                          ggplot2::aes(x=plotdata$time, y=plotdata$y,
@@ -555,12 +573,30 @@ timeplot <- function(network, level="treatment", plotby="arm", link="identity",
           )
     }
 
+    # Handle cfb data
+    studies <- unique(diffs$studyID)
+    diffs$bl <- FALSE
+    for (i in seq_along(cfb)) {
+      if (cfb[i]==FALSE) {
+        diffs$bl[diffs$studyID==studies[i] & diffs$fupcount.x==1 & diffs$fupcount.y==1] <- TRUE
+      }
+    }
 
-    diffs <- diffs %>%
-      dplyr::bind_rows(diffs %>%
-                         dplyr::group_by(.data$studyID, .data$arm.x, .data$arm.y) %>%
-                         dplyr::slice(1) %>%
-                         dplyr::mutate(time=0, pairDiff=0))
+
+    # diffs <- diffs %>%
+    #   dplyr::bind_rows(diffs %>%
+    #                      dplyr::group_by(.data$studyID, .data$arm.x, .data$arm.y) %>%
+    #                      dplyr::slice(1) %>%
+    #                      dplyr::mutate(time=0, pairDiff=0))
+
+    diffs <- diffs %>% dplyr::bind_rows(diffs %>% dplyr::group_by(.data$studyID,
+                                                                  .data$arm.x, .data$arm.y) %>%
+                                          dplyr::slice(1) %>%
+                                          dplyr::mutate(time=dplyr::case_when(bl==0 ~ 0),
+                                                        pairDiff=dplyr::case_when(bl==0 ~ 0),
+                                                        bl=dplyr::case_when(bl==0 ~ 1)))
+
+    diffs <- diffs[!is.na(diffs$time),]
 
     if (level=="class") {
 
@@ -1023,3 +1059,101 @@ theme_mbnma <- function(...) {
       strip.text = ggplot2::element_text(colour = "black")
     )
 }
+
+
+
+
+
+
+
+#' Plot cumulative ranking curves from MBNMA models
+#'
+#' @param x An object of class `"mb.rank"` generated by `rank.mbnma()`
+#' @param sucra A logical object to indicate whether Surface Under Cumulative Ranking Curve (SUCRA)
+#' values should be calculated and returned as a data frame. Areas calculated
+#' using \code{\link[rgeos]{readWKT}}.
+#' @param ... Arguments to be sent to `ggplot::geom_line()`
+#' @inheritParams rank.mbnma
+#'
+#' @return Line plots showing the cumulative ranking probabilities for each agent/class and
+#' dose-response parameter in `x`. The object returned is a list which contains the plot
+#' (an object of `class(c("gg", "ggplot")`) and a data frame of SUCRA values
+#' if `sucra = TRUE`.
+#'
+#' @examples
+#' \donttest{
+#' # Using the alogliptin data
+#' network <- mb.network(alog_pcfb)
+#'
+#' # Estimate rankings  from an Emax dose-response MBNMA
+#' emax <- mb.run(network, fun=temax())
+#' ranks <- rank(emax, params=c("emax", "et50", "auc"))
+#'
+#' # Plot cumulative rankings for both dose-response parameters simultaneously
+#' # Note that SUCRA values are also returned
+#' cumrank(ranks)
+#' }
+#' @export
+cumrank <- function(x, params=NULL, sucra=TRUE, ...) {
+
+  # Run checks
+  argcheck <- checkmate::makeAssertCollection()
+  checkmate::assertClass(x, "mb.rank", add=argcheck)
+  checkmate::assertCharacter(params, null.ok=TRUE, add=argcheck)
+  checkmate::assertLogical(sucra, null.ok=FALSE, add=argcheck)
+  checkmate::reportAssertions(argcheck)
+
+  output <- list()
+
+  if (is.null(params)) {
+    params <- names(x)
+  }
+
+  df <- data.frame()
+  for (param in seq_along(params)) {
+    if (!params[param] %in% names(x)) {
+      stop(paste0(params[param], " is not a ranked parameter in x"))
+    }
+
+    cum.mat <- x[[params[param]]]$cum.matrix
+    treats <- colnames(cum.mat)
+
+    melt <- reshape2::melt(cum.mat)
+    melt$param <- params[param]
+
+    df <- rbind(df, melt)
+
+  }
+
+  df$Parameter <- factor(df$param)
+
+  g <- ggplot2::ggplot(df, ggplot2::aes(x=Var1, y=value, linetype=Parameter, colour=Parameter), ...) +
+    ggplot2::geom_line(size=1)
+
+  g <- g + ggplot2::facet_wrap(~factor(Var2)) +
+    ggplot2::xlab("Rank (1 = best)") +
+    ggplot2::ylab("Cumulative probability") +
+    ggplot2::labs(linetype="Parameter", colour="Parameter") +
+    theme_mbnma()
+
+  graphics::plot(g)
+
+  output <- list("cumplot"=g)
+
+  # Calculate AUC
+  if (sucra==TRUE) {
+    df.auc <- df %>%
+      dplyr::group_by(df$Var2, df$param) %>%
+      dplyr::do(data.frame(sucra=calcauc(.)))
+
+    df.auc <- dplyr::ungroup(df.auc)
+
+    names(df.auc) <- c("treatment", "parameter", "sucra")
+
+    output[["sucra"]] <- df.auc
+
+    print(df.auc)
+  }
+
+  return(invisible(output))
+}
